class IRCColor:

    JOIN = (64, 164, 64)
    POS_MODE = (64, 164, 64)

    PART = (164, 64, 64)
    NEG_MODE = (164, 64, 64)

    KICK = (255, 64, 64)
    WARNING = (255, 0, 0)

    INFO = (64, 128, 255)

    MESSAGE = (0, 0, 0)
    MY_MESSAGE = (164, 164, 164)

    TOPIC = (192, 128, 0)

    NOTICE = (164, 64, 164)

